@@ -17,6 +17,8 @@ def nestedShit(pureScript, fill, prevPageIndex, prevContentIndex, prevSceneIndex
 
                     prevSceneIndex += 1
                 prevSceneIndex = 0
+            else:
+                content["duration"] = fill
             prevContentIndex += 1
         prevContentIndex = 0
         prevPageIndex += 1
@@ -37,6 +39,7 @@ def fillTimestamps(pureScript):
         contentIndex = 0
         if "type" in page and page["type"] == "FIRST_PAGES":
             pageIndex += 1
+            countInBetween += 1
             continue
         while contentIndex < len(page["content"]):
             sceneIndex = 0
@@ -65,7 +68,7 @@ def fillTimestamps(pureScript):
                         else False
                     )
                     startTimestamp = copy.copy(scene["timestamp"])
-                    if firstTimestamp:
+                    if not firstTimestamp:
                         del scene["timestamp"]
 
                     countInBetween = 0
